pub struct PySimulationReport {
pub total_steps: u64,
pub total_time: f64,
pub energy: PyEnergyTracker,
pub momentum: PyMomentumTracker,
pub collision: PyCollisionStats,
pub sleep: PySleepStats,
pub constraint: PyConstraintStats,
pub performance: PyPerformanceTracker,
pub anomaly_list: Vec<String>,
}Expand description
A full simulation quality report.
Fields
total_steps: u64Total steps simulated.
total_time: f64Total simulation time (s).
energy: PyEnergyTrackerEnergy summary.
momentum: PyMomentumTrackerMomentum summary.
collision: PyCollisionStatsCollision stats.
sleep: PySleepStatsSleep stats.
constraint: PyConstraintStatsConstraint stats.
performance: PyPerformanceTrackerPerformance stats.
anomaly_list: Vec<String>List of anomalies as human-readable strings.
Implementations
Sourceimpl PySimulationReport
impl PySimulationReport
Sourcepub fn flag_anomaly(&mut self, msg: impl Into<String>)
pub fn flag_anomaly(&mut self, msg: impl Into<String>)
Append an anomaly message.
Sourcepub fn check_energy(&mut self)
pub fn check_energy(&mut self)
Run a check and flag if energy anomalies exist.
Sourcepub fn check_momentum(&mut self)
pub fn check_momentum(&mut self)
Run a check and flag if momentum is not conserved.