PyFemMesh

Struct PyFemMesh 

pub struct PyFemMesh {
    pub nodes: Vec<PyFemNode>,
    pub elements: Vec<PyFemElement>,
    pub materials: Vec<PyFemMaterial>,
    pub dirichlet_bcs: Vec<PyFemDirichletBC>,
    pub nodal_forces: Vec<PyFemNodalForce>,
}
A 2-D FEM mesh with nodes, elements, materials, and boundary conditions.

Fields

nodes: Vec<PyFemNode>

All nodes in the mesh.

elements: Vec<PyFemElement>

All triangular elements in the mesh.

materials: Vec<PyFemMaterial>

Material library.

dirichlet_bcs: Vec<PyFemDirichletBC>

Dirichlet (fixed) boundary conditions.

nodal_forces: Vec<PyFemNodalForce>

Nodal force loads.

Implementations

Source

impl PyFemMesh

pub fn new() -> Self

Create an empty mesh.

pub fn add_node(&mut self, x: f64, y: f64) -> usize

Add a node at (x, y). Returns node index.

pub fn add_material(&mut self, mat: PyFemMaterial) -> usize

Add a material. Returns material index.

pub fn add_element(&mut self, n0: usize, n1: usize, n2: usize) -> usize

Add a CST element connecting nodes n0, n1, n2. Returns element index.

pub fn add_element_with_material( &mut self, n0: usize, n1: usize, n2: usize, material_id: usize, thickness: f64, ) -> usize

Add a CST element with explicit material and thickness. Returns element index.

pub fn add_dirichlet_bc(&mut self, bc: PyFemDirichletBC)

Add a Dirichlet boundary condition.

pub fn pin_node(&mut self, node: usize)

Pin both DOFs of node (fix x and y to zero).

pub fn apply_nodal_force(&mut self, node: usize, fx: f64, fy: f64)

Apply a nodal force at node.

pub fn num_dofs(&self) -> usize

Number of degrees of freedom (2 per node).

pub fn num_nodes(&self) -> usize

Number of nodes.

pub fn num_elements(&self) -> usize

Number of elements.

pub fn element_area(&self, e: usize) -> f64

Compute the signed area of triangular element e.

pub fn build_rectangle( &mut self, ox: f64, oy: f64, lx: f64, ly: f64, nx: usize, ny: usize, material_id: usize, thickness: f64, ) -> usize

Build a simple structured rectangular mesh of triangles.

Creates a nx × ny grid of quads, each quad split into 2 triangles. Bottom-left corner at (ox, oy), domain size (lx, ly). Returns the number of nodes added.

Source

impl PyFemMesh

pub fn bounding_box(&self) -> Option<[f64; 4]>

Return the bounding box of all nodes as [xmin, ymin, xmax, ymax].

pub fn total_area(&self) -> f64

Return the total area of all elements (sum of |area_i|).

pub fn element_centroid(&self, e: usize) -> Option<[f64; 2]>

Return the centroid of element e as [cx, cy].

pub fn closest_node(&self, px: f64, py: f64) -> Option<usize>

Find the node closest to position (px, py).

pub fn left_boundary_nodes(&self, tol: f64) -> Vec<usize>

Return nodes on the left boundary (x <= xmin + tol).

pub fn right_boundary_nodes(&self, tol: f64) -> Vec<usize>

Return nodes on the right boundary (x >= xmax - tol).

pub fn pin_left_boundary(&mut self, tol: f64)

Pin all nodes on the left boundary.