pub struct PyFemSolveResult {
pub displacements: Vec<f64>,
pub von_mises_stress: Vec<f64>,
pub solver_iterations: usize,
pub residual_norm: f64,
pub converged: bool,
}Expand description
Result of a FEM linear static solve.
Fields
displacements: Vec<f64>Nodal displacement vector (flat: [ux0, uy0, ux1, uy1, …]).
von_mises_stress: Vec<f64>Von Mises stress per element.
solver_iterations: usizeNumber of CG solver iterations used.
residual_norm: f64Residual norm at convergence.
converged: boolWhether the solver converged.
Implementations
Sourceimpl PyFemSolveResult
impl PyFemSolveResult
Sourcepub fn node_displacement(&self, i: usize) -> Option<[f64; 2]>
pub fn node_displacement(&self, i: usize) -> Option<[f64; 2]>
Displacement of node i as [ux, uy].
Sourcepub fn max_von_mises(&self) -> f64
pub fn max_von_mises(&self) -> f64
Maximum von Mises stress over all elements.
Sourcepub fn mean_von_mises(&self) -> f64
pub fn mean_von_mises(&self) -> f64
Mean von Mises stress.
Sourceimpl PyFemSolveResult
impl PyFemSolveResult
Sourcepub fn displacement_pairs(&self) -> Vec<[f64; 2]>
pub fn displacement_pairs(&self) -> Vec<[f64; 2]>
Return the displacement field as a list of [ux, uy] pairs.
Sourcepub fn max_displacement_magnitude(&self) -> f64
pub fn max_displacement_magnitude(&self) -> f64
Maximum absolute displacement component.
Sourcepub fn sorted_von_mises(&self) -> Vec<f64>
pub fn sorted_von_mises(&self) -> Vec<f64>
Return all von Mises stresses as a sorted (ascending) copy.
Sourcepub fn von_mises_quantile(&self, q: f64) -> f64
pub fn von_mises_quantile(&self, q: f64) -> f64
Return the q-th quantile of the von Mises stress distribution (q in [0,1]).