pub fn convex_hull_from_mesh(mesh: &PyTriangleMesh) -> PyConvexHullExpand description
Compute the convex hull of all vertices in a mesh.
pub fn convex_hull_from_mesh(mesh: &PyTriangleMesh) -> PyConvexHullCompute the convex hull of all vertices in a mesh.