pub struct PyIslandStats {
pub island_id: u32,
pub body_count: usize,
pub constraint_count: usize,
pub sleep_timer: f64,
pub energy: f64,
}Expand description
Statistics for a simulation island.
An island is a group of bodies connected by contacts or constraints.
Fields
island_id: u32Island identifier.
body_count: usizeNumber of bodies in this island.
constraint_count: usizeNumber of constraints (contacts + joints) in this island.
sleep_timer: f64Accumulated time all bodies have been below sleep threshold (seconds).
energy: f64Total kinetic energy of the island.
Implementations