pub fn save_snapshot(world: &PyPhysicsWorld) -> StringExpand description
Serialize the current state of world into a compact JSON string.
pub fn save_snapshot(world: &PyPhysicsWorld) -> StringSerialize the current state of world into a compact JSON string.