pub fn save_snapshot_pretty(world: &PyPhysicsWorld) -> StringExpand description
Serialize the current state of world into a pretty-printed JSON string.
pub fn save_snapshot_pretty(world: &PyPhysicsWorld) -> StringSerialize the current state of world into a pretty-printed JSON string.