pub struct PySceneGraph {
pub nodes: Vec<PySceneNode>,
pub meshes: Vec<(u32, PyMeshRenderer)>,
pub particles: Vec<(u32, PyParticleRenderer)>,
pub lights: Vec<PyLight>,
/* private fields */
}Expand description
Hierarchical scene graph managing nodes, meshes, particles and lights.
Fields
nodes: Vec<PySceneNode>All nodes in the scene.
meshes: Vec<(u32, PyMeshRenderer)>Mesh renderers attached to node ids.
particles: Vec<(u32, PyParticleRenderer)>Particle renderers attached to node ids.
lights: Vec<PyLight>Lights in the scene.
Implementations
Sourceimpl PySceneGraph
impl PySceneGraph
Sourcepub fn add_mesh(&mut self, node_id: u32, mesh: PyMeshRenderer)
pub fn add_mesh(&mut self, node_id: u32, mesh: PyMeshRenderer)
Attach a mesh to a node.
Sourcepub fn add_particles(&mut self, node_id: u32, particles: PyParticleRenderer)
pub fn add_particles(&mut self, node_id: u32, particles: PyParticleRenderer)
Attach particles to a node.
Sourcepub fn set_visible(&mut self, node_id: u32, visible: bool)
pub fn set_visible(&mut self, node_id: u32, visible: bool)
Set visibility for a node.
Sourcepub fn set_translation(&mut self, node_id: u32, translation: [f64; 3])
pub fn set_translation(&mut self, node_id: u32, translation: [f64; 3])
Set local translation for a node.
Sourcepub fn traverse_visible(&self) -> Vec<u32>
pub fn traverse_visible(&self) -> Vec<u32>
Traverse all visible nodes and return their ids in order.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Return total number of nodes.