pub struct PyIsland {
pub id: u32,
pub bodies: Vec<u32>,
pub constraints: Vec<u32>,
pub sleep_state: IslandSleepState,
pub quiet_frames: u32,
pub sleep_threshold: f64,
pub sleep_frames: u32,
}Expand description
An island groups bodies and constraints that can interact.
Fields
id: u32Unique island id.
bodies: Vec<u32>Handles of rigid bodies in this island.
constraints: Vec<u32>Handles of constraints in this island.
sleep_state: IslandSleepStateSleep state.
quiet_frames: u32Frames below the velocity threshold (used for sleep triggering).
sleep_threshold: f64Velocity threshold for sleeping (m/s and rad/s combined).
sleep_frames: u32Number of frames needed to trigger sleep.
Implementations
Sourceimpl PyIsland
impl PyIsland
Sourcepub fn add_constraint(&mut self, constraint: u32)
pub fn add_constraint(&mut self, constraint: u32)
Add a constraint to the island.
Sourcepub fn update_sleep(&mut self, max_speed: f64)
pub fn update_sleep(&mut self, max_speed: f64)
Update sleep state given the maximum body speed this frame.