pub struct PyConvexHull {
pub vertices: Vec<[f64; 3]>,
}Expand description
A convex hull stored as a list of vertices.
The hull is not computed internally; the caller is responsible for providing convex vertices. Methods here are geometry helpers.
Fields
vertices: Vec<[f64; 3]>Vertices of the convex hull.
Implementations
Sourceimpl PyConvexHull
impl PyConvexHull
Sourcepub fn vertex_count(&self) -> usize
pub fn vertex_count(&self) -> usize
Number of vertices in the hull.
Sourcepub fn may_contain_point(&self, p: [f64; 3]) -> bool
pub fn may_contain_point(&self, p: [f64; 3]) -> bool
Naively check if a point is “inside” the hull by checking it is within the AABB (a conservative, approximate test).